.. _introduction:

************
Introduction
************


`qualpipe` is a Python-based automation tool for the
CTAO data quality evaluations.
It leverages the `ctapipe <https://github.com/cta-observatory/ctapipe>`_ library to process telescope monitoring data
and applies configurable quality criteria to ensure that
the collected data meets desired standards.

.. _features:

Features
========

* Define and apply quality checks to monitoring data based on configuration files.
* Modular and extensible framework for describing and validating data.
* Supports processing with telescope-specific criteria.
* YAML configuration for easy adaptability.
